==> codelink_1.20.0.tgz: codelink/doc/CodelinkSet.R <==
###################################################
### chunk number 1: readfile1 eval=FALSE
###################################################
## #line 40 "CodelinkSet.Rnw"
## 
## cset <- readCodelinkSet("targets.txt")
## 


###################################################
### chunk number 2: annotations
###################################################
#line 54 "CodelinkSet.Rnw"

library(codelink)
data(codelink.exprset)
annotation(codelink.exprset)
annotation(codelink.exprset) <- "rwgcod"
annotation(codelink.exprset)



###################################################
### chunk number 3: preprocess
###################################################
#line 83 "CodelinkSet.Rnw"

cset <- codPreprocess(codelink.exprset)



###################################################
### chunk number 4: plot
###################################################
#line 92 "CodelinkSet.Rnw"

codPlot(cset, what = "density")
codPlot(cset, what = "ma")
codPlot(cset, what = "image")



###################################################
### chunk number 5: fit eval=FALSE
###################################################
## #line 107 "CodelinkSet.Rnw"
## 
## design <- model.matrix(~ -1 + factor(cset$Treatment))
## fit <- lmFit(cset, design)
## 


###################################################
### chunk number 6: fit eval=FALSE
###################################################
## #line 118 "CodelinkSet.Rnw"
## 
## writeCodelink(codelink.exprset, file = "intensities.txt")
## 


###################################################
### chunk number 7: fit eval=FALSE
###################################################
## #line 128 "CodelinkSet.Rnw"
## 
## foo.avg <- averageProbes(codelink.exprset)
## 


###################################################
### chunk number 8: sessioninfo
###################################################
#line 139 "CodelinkSet.Rnw"

sessionInfo()

==> codelink_1.26.0.tgz: codelink/doc/CodelinkSet.R <==
### R code from vignette source 'CodelinkSet.Rnw'
### Encoding: ASCII

###################################################
### code chunk number 1: readfile1 (eval = FALSE)
###################################################
## 
## cset <- readCodelinkSet("targets.txt")
## 


###################################################
### code chunk number 2: annotations
###################################################

library(codelink)
data(codelink.exprset)
annotation(codelink.exprset)
annotation(codelink.exprset) <- "rwgcod"
annotation(codelink.exprset)



###################################################
### code chunk number 3: preprocess
###################################################

cset <- codPreprocess(codelink.exprset)



###################################################
### code chunk number 4: plot
###################################################

codPlot(cset, what = "density")
codPlot(cset, what = "ma")
codPlot(cset, what = "image")



###################################################
### code chunk number 5: fit
###################################################

# assign example experimental conditions:
cset$Treatment = c("C", "C", "T", "T")
# create and fit model:
design <- model.matrix(~ -1 + factor(cset$Treatment))
fit <- lmFit(cset, design)



###################################################
### code chunk number 6: fit (eval = FALSE)
###################################################
## 
## writeCodelink(codelink.exprset, file = "intensities.txt")
## 


###################################################
### code chunk number 7: fit (eval = FALSE)
###################################################
## 
## foo.avg <- averageProbes(codelink.exprset)
## 


###################################################
### code chunk number 8: sessioninfo
###################################################

sessionInfo()
